Run in a container
==================

Pre-built containers with ibek and its dependencies already
installed are available on `Github Container Registry
<https://ghcr.io/epics-containers/ibek>`_.

Starting the container
----------------------

To pull the container from github container registry and run::

    $ docker run ghcr.io/epics-containers/ibek:main --version

To get a released version, use a numbered release instead of ``change_linter_to_ruff``.
